@@ -12,7 +12,7 @@ xross = {
         }
         $(function(){
             $.each($('.' + xross_class), function(idx, obj) {
-                xross.describe( '#' + $(obj).attr('id'), handler_name);
+                xross.describe('#' + $(obj).attr('id'), handler_name);
             });
         });
     },
@@ -86,6 +86,21 @@ xross = {
             }
         },
 
+        get_function: function(name, context) {
+            var path_chunks = name.split('.'),
+                func = path_chunks.pop();
+
+            for (var i = 0; i < path_chunks.length; i++) {
+                context = context[path_chunks[i]];
+                if (context === undefined) {
+                    xross.utils.log(function(){ return 'Unable to find `' + name + '` function.' });
+                    return undefined;
+                }
+            }
+
+            return context[func];
+        },
+
         get_element_data: function(el) {
             var data_filtered = {},
                 prefix = xross.data_items_prefix;
@@ -107,7 +122,7 @@ xross = {
     handlers: {
         ajax: {
             func: function(el_selector, params) {
-                var el_scope = el_selector,
+                var event_target = el_selector,
                     $el = $(el_selector),
                     operation_id = $el.attr('id');
 
@@ -141,8 +156,8 @@ xross = {
                         xross.utils.log(function(){ return 'Skipping binding `ready` for not found `' + el_selector + '` element.' });
                         return;
                     }
-                    // ready is used only for document object, so we force a new scope
-                    el_scope = {};
+                    // ready is used only for document object, so we force a new event target
+                    event_target = {};
                 }
 
                 if (typeof params.target==='string') {
@@ -156,27 +171,50 @@ xross = {
                     }
                 }
 
-                if (typeof params.success==='string') {
-                    var func = {
-                            fill: function(target, data) { target.html(data); },
-                            replace: function(target, data) { target.replaceWith(data); },
-                            append: function(target, data) { target.append(data); },
-                            prepend: function(target, data) { target.prepend(data); }
-                        }[params.success];
+                if (typeof params.complete==='string') {
+                    params.complete = xross.utils.get_function(params.complete, window);
+                }
 
-                    params.success = function(target) {
-                        return function(data, status, xhr) {
-                            xross.utils.log(function(){ return 'Running generic ajax success function for `' + el_selector + '` element.' });
-                            func($(xross.utils.evaluate(target, $el)), data);
-                        }
+                if (typeof params.success==='string') {
+                    var func_name = params.success,
+                        func = xross.utils.get_function(func_name, {
+                            fill: function(data, status, xhr, target) { target.html(data); },
+                            replace: function(data, status, xhr, target) { target.replaceWith(data); },
+                            append: function(data, status, xhr, target) { target.append(data); },
+                            prepend: function(data, status, xhr, target) { target.prepend(data); }
+                        });
+
+                    if (func===undefined) {
+                        func = xross.utils.get_function(func_name, window);
+                    }
+
+                    params.success = function(data, status, xhr) {
+                        xross.utils.log(function(){ return 'Running `' + func_name + '` success function for `' + el_selector + '` element.' });
+                        func(data, status, xhr, $(xross.utils.evaluate(params.target, $el)));
                     };
                 }
 
-                params.success = xross.utils.evaluate(params.success, params.target);
+                if (typeof params.error==='string') {
+                    var err_func_name = params.error,
+                        err_func = xross.utils.get_function(err_func_name, {
+                            log: function(xhr, status, error) {
+                                xross.utils.log(function(){ return 'Request failed `' + error + '`: `' + xhr.responseText + '`.' });
+                            }
+                        });
+
+                    if (err_func===undefined) {
+                        err_func = xross.utils.get_function(err_func_name, window);
+                    }
+
+                    params.error = function(xhr, status, error) {
+                        xross.utils.log(function(){ return 'Running `' + err_func_name + '` error function for `' + el_selector + '` element.' });
+                        err_func(xhr, status, error);
+                    };
+                }
 
                 xross.utils.log(function(){ return 'Binding `' + params.event + '` for `' + el_selector + '`.' });
 
-                $(document).on(params.event, el_scope, function(e) {
+                $(document).on(params.event, event_target, function(e) {
                     var data = $.extend({}, { op: operation_id }, xross.utils.get_element_data($(el_selector))),
                         form = null;
                     xross.utils.log(function(){ return 'Triggering `' + params.event + '` for `' + el_selector + '` with `' + $.param(data) + '`.' });
@@ -192,9 +230,10 @@ xross = {
                     }
                     $.ajax({
                         type: params.method,
-                        // Consider .
                         data: data,
-                        success: params.success,
+                        success: params.success,  // data, status, xhr
+                        error: params.error,  // xhr, status, error
+                        complete: params.complete,  // xhr, status
                         cache: false,
                         dataType: 'html'
                     });
@@ -207,6 +246,8 @@ xross = {
                 event: 'auto',
                 target: 'this',
                 success: 'fill',
+                error: 'log',
+                complete: null,
                 form: null,
                 op: null
             }
